@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Google LLC
+# Copyright 2023 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,6 +19,10 @@ from typing import Dict, Type
 from .base import IdentityAwareProxyAdminServiceTransport
 from .grpc import IdentityAwareProxyAdminServiceGrpcTransport
 from .grpc_asyncio import IdentityAwareProxyAdminServiceGrpcAsyncIOTransport
+from .rest import (
+    IdentityAwareProxyAdminServiceRestInterceptor,
+    IdentityAwareProxyAdminServiceRestTransport,
+)
 
 # Compile a registry of transports.
 _transport_registry = (
@@ -26,9 +30,12 @@ _transport_registry = (
 )  # type: Dict[str, Type[IdentityAwareProxyAdminServiceTransport]]
 _transport_registry["grpc"] = IdentityAwareProxyAdminServiceGrpcTransport
 _transport_registry["grpc_asyncio"] = IdentityAwareProxyAdminServiceGrpcAsyncIOTransport
+_transport_registry["rest"] = IdentityAwareProxyAdminServiceRestTransport
 
 __all__ = (
     "IdentityAwareProxyAdminServiceTransport",
     "IdentityAwareProxyAdminServiceGrpcTransport",
     "IdentityAwareProxyAdminServiceGrpcAsyncIOTransport",
+    "IdentityAwareProxyAdminServiceRestTransport",
+    "IdentityAwareProxyAdminServiceRestInterceptor",
 )
