@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Google LLC
+# Copyright 2023 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -55,6 +55,7 @@ from .transports.base import (
 )
 from .transports.grpc import IdentityAwareProxyOAuthServiceGrpcTransport
 from .transports.grpc_asyncio import IdentityAwareProxyOAuthServiceGrpcAsyncIOTransport
+from .transports.rest import IdentityAwareProxyOAuthServiceRestTransport
 
 
 class IdentityAwareProxyOAuthServiceClientMeta(type):
@@ -72,6 +73,7 @@ class IdentityAwareProxyOAuthServiceClientMeta(type):
     _transport_registry[
         "grpc_asyncio"
     ] = IdentityAwareProxyOAuthServiceGrpcAsyncIOTransport
+    _transport_registry["rest"] = IdentityAwareProxyOAuthServiceRestTransport
 
     def get_transport_class(
         cls,
@@ -278,7 +280,7 @@ class IdentityAwareProxyOAuthServiceClient(
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -1113,7 +1115,7 @@ class IdentityAwareProxyOAuthServiceClient(
             metadata=metadata,
         )
 
-    def __enter__(self):
+    def __enter__(self) -> "IdentityAwareProxyOAuthServiceClient":
         return self
 
     def __exit__(self, type, value, traceback):
