@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Google LLC
+# Copyright 2023 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from __future__ import annotations
+
 from typing import MutableMapping, MutableSequence
 
 from google.protobuf import duration_pb2  # type: ignore
@@ -273,10 +275,14 @@ class UpdateIapSettingsRequest(proto.Message):
             Authorization: Requires the ``updateSettings`` permission
             for the associated resource.
         update_mask (google.protobuf.field_mask_pb2.FieldMask):
-            The field mask specifying which IAP settings
-            should be updated. If omitted, the all of the
-            settings are updated. See
-            https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#fieldmask
+            The field mask specifying which IAP settings should be
+            updated. If omitted, then all of the settings are updated.
+            See
+            https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#fieldmask.
+
+            Note: All IAP reauth settings must always be set together,
+            using the field mask:
+            ``iapSettings.accessSettings.reauthSettings``.
     """
 
     iap_settings: "IapSettings" = proto.Field(
@@ -432,6 +438,9 @@ class OAuthSettings(proto.Message):
             Note: IAP does not verify that the id token's hd
             claim matches this value since access behavior
             is managed by IAM policies.
+        programmatic_clients (MutableSequence[str]):
+            List of OAuth client IDs allowed to
+            programmatically authenticate with IAP.
     """
 
     login_hint: wrappers_pb2.StringValue = proto.Field(
@@ -439,6 +448,10 @@ class OAuthSettings(proto.Message):
         number=2,
         message=wrappers_pb2.StringValue,
     )
+    programmatic_clients: MutableSequence[str] = proto.RepeatedField(
+        proto.STRING,
+        number=5,
+    )
 
 
 class ReauthSettings(proto.Message):
@@ -458,14 +471,41 @@ class ReauthSettings(proto.Message):
     """
 
     class Method(proto.Enum):
-        r"""Types of reauthentication methods supported by IAP."""
+        r"""Types of reauthentication methods supported by IAP.
+
+        Values:
+            METHOD_UNSPECIFIED (0):
+                Reauthentication disabled.
+            LOGIN (1):
+                Prompts the user to log in again.
+            PASSWORD (2):
+                No description available.
+            SECURE_KEY (3):
+                User must use their secure key 2nd factor
+                device.
+            ENROLLED_SECOND_FACTORS (4):
+                User can use any enabled 2nd factor.
+        """
         METHOD_UNSPECIFIED = 0
         LOGIN = 1
         PASSWORD = 2
         SECURE_KEY = 3
+        ENROLLED_SECOND_FACTORS = 4
 
     class PolicyType(proto.Enum):
-        r"""Type of policy in the case of hierarchial policies."""
+        r"""Type of policy in the case of hierarchial policies.
+
+        Values:
+            POLICY_TYPE_UNSPECIFIED (0):
+                Default value. This value is unused.
+            MINIMUM (1):
+                This policy acts as a minimum to other
+                policies, lower in the hierarchy. Effective
+                policy may only be the same or stricter.
+            DEFAULT (2):
+                This policy acts as a default if no other
+                reauth policy is set.
+        """
         POLICY_TYPE_UNSPECIFIED = 0
         MINIMUM = 1
         DEFAULT = 2
@@ -626,30 +666,35 @@ class AttributePropagationSettings(proto.Message):
     Attributes:
         expression (str):
             Raw string CEL expression. Must return a list of attributes.
-            Maximum of 45 attributes can be selected. Expressions can
+            A maximum of 45 attributes can be selected. Expressions can
             select different attribute types from ``attributes``:
             ``attributes.saml_attributes``,
-            ``attributes.iap_attributes``. Limited functions are
+            ``attributes.iap_attributes``. The following functions are
             supported:
 
-            -  ``filter: <list>.filter(<iter_var>, <predicate>)`` ->
-               returns a subset of ``<list>`` where ``<predicate>`` is
+            -  filter ``<list>.filter(<iter_var>, <predicate>)``:
+               Returns a subset of ``<list>`` where ``<predicate>`` is
                true for every item.
-            -  ``in: <var> in <list>`` -> returns true if ``<list>``
-               contains ``<var>``
-            -  ``selectByName: <list>.selectByName(<string>)`` ->
-               returns the attribute in ``<list>`` with the given
-               ``<string>`` name, otherwise returns empty.
-            -  ``emitAs: <attribute>.emitAs(<string>)`` -> sets the
+
+            -  in ``<var> in <list>``: Returns true if ``<list>``
+               contains ``<var>``.
+
+            -  selectByName ``<list>.selectByName(<string>)``: Returns
+               the attribute in ``<list>`` with the given ``<string>``
+               name, otherwise returns empty.
+
+            -  emitAs ``<attribute>.emitAs(<string>)``: Sets the
                ``<attribute>`` name field to the given ``<string>`` for
                propagation in selected output credentials.
-            -  ``strict: <attribute>.strict()`` -> ignore the
+
+            -  strict ``<attribute>.strict()``: Ignores the
                ``x-goog-iap-attr-`` prefix for the provided
-               ``<attribute>`` when propagating via the ``HEADER``
-               output credential, i.e. request headers.
-            -  ``append: <target_list>.append(<attribute>)`` OR
-               ``<target_list>.append(<list>)`` -> append the provided
-               ``<attribute>`` or ``<list>`` onto the end of
+               ``<attribute>`` when propagating with the ``HEADER``
+               output credential, such as request headers.
+
+            -  append ``<target_list>.append(<attribute>)`` OR
+               ``<target_list>.append(<list>)``: Appends the provided
+               ``<attribute>`` or ``<list>`` to the end of
                ``<target_list>``.
 
             Example expression:
@@ -676,6 +721,19 @@ class AttributePropagationSettings(proto.Message):
         output credential maps to a "field" in the response. For
         example, selecting JWT will propagate all attributes in the IAP
         JWT, header in the headers, etc.
+
+        Values:
+            OUTPUT_CREDENTIALS_UNSPECIFIED (0):
+                An output credential is required.
+            HEADER (1):
+                Propagate attributes in the headers with
+                "x-goog-iap-attr-" prefix.
+            JWT (2):
+                Propagate attributes in the JWT of the form:
+                ``"additional_claims": { "my_attribute": ["value1", "value2"] }``
+            RCTOKEN (3):
+                Propagate attributes in the RCToken of the form:
+                ``"additional_claims": { "my_attribute": ["value1", "value2"] }``
         """
         OUTPUT_CREDENTIALS_UNSPECIFIED = 0
         HEADER = 1
